@@ -2,10 +2,9 @@ package parse
 
 import (
 	"fmt"
-
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/gohcl"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/options"
 )
 
@@ -22,7 +21,7 @@ func DecodeOptions(block *hcl.Block, overrides ...BlockMappingOverride) (options
 		diags = append(diags, &hcl.Diagnostic{
 			Severity: hcl.DiagError,
 			Summary:  fmt.Sprintf("Unexpected options type '%s'", block.Labels[0]),
-			Subject:  hclhelpers.BlockRangePointer(block),
+			Subject:  hcl_helpers.BlockRangePointer(block),
 		})
 		return nil, diags
 	}
